irisrpart_documentation: Iris rpart Shiny App

Description

Description

This Shiny app take the number of splits (1 to 4) from the user and fit a classification tree using rpart package.

With the fited tree, it creats a plot using rpart.plot package a ROC curve using multiROC package.


qymera0/irisrpart documentation built on June 19, 2020, 12:18 a.m.