This Shiny app take the number of splits (1 to 4) from the user and fit a classification tree using rpart package.
With the fited tree, it creats a plot using rpart.plot package a ROC curve using multiROC package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.